@@ -19,28 +19,25 @@ generate Model Cards from trained models within ML pipelines.
 
 import json
 import os
-import os.path
-import shutil
+import pkgutil
 import tempfile
-from typing import Any, Dict, Optional, Text
+from typing import Optional, Text
 
 from absl import logging
 import jinja2
-import jsonschema
 
-from model_card_toolkit import model_card as model_card_module
+from model_card_toolkit.model_card import ModelCard
 from model_card_toolkit.utils import graphics
 from model_card_toolkit.utils import tfx_util
+from model_card_toolkit.utils import validation
 
-import semantic_version
+import ml_metadata as mlmd
 
-from ml_metadata.metadata_store import metadata_store
-
-# Constants about versioned JSON schema files for Model Card.
-_SCHEMA_DIR = os.path.join(os.path.dirname(__file__), 'schema')
-_SCHEMA_FILE_NAME = 'model_card.schema.json'
 # Constants about provided UI templates.
-_UI_TEMPLATE_DIR = os.path.join(os.path.dirname(__file__), 'template')
+_UI_TEMPLATES = (
+    'template/html/default_template.html.jinja',
+    'template/md/default_template.md.jinja',
+)
 _DEFAULT_UI_TEMPLATE_FILE = os.path.join('html', 'default_template.html.jinja')
 # Constants about Model Cards Toolkit Assets (MCTA).
 _MCTA_JSON_FILE = 'data/model_card.json'
@@ -52,19 +49,47 @@ _MODEL_CARDS_DIR = 'model_cards/'
 
 
 class ModelCardToolkit():
-  """Model Cards Toolkit (MCT) provides utilities to generate a ModelCard.
+  """ModelCardToolkit provides utilities to generate a ModelCard.
 
-  Given a model, a ModelCardToolkit finds related metadata and lineage from a
-  MLMD instance and generates a ModelCard about the model in various output
-  formats (e.g., HTML). The ModelCardToolkit includes a list of APIs designed
-  for a human-in-the-loop process to elaborate the ModelCard. It organizes the
-  ModelCard assets (e.g., structured data, plots, and UI templates) in a user
-  specified directory, and updates them incrementally via the APIs.
+  ModelCardToolkit is a tool for ML practitioners to create Model Cards,
+  documentation for model information such as owners, use cases, training and
+  evaluation data, performance, etc. A Model Card document can be displayed in
+  output formats including HTML, Markdown, etc.
+
+  The ModelCardToolkit includes an API designed for a human-in-the-loop process
+  to elaborate the ModelCard. If model training is integrated with ML Metadata
+  (e.g., TFX pipelines), the ModelCardToolkit can further populate ModelCard
+  fields by extract metadata and lineage from the model's MLMD instance.
+
+  The ModelCardToolkit organizes the ModelCard assets (e.g., structured data,
+  plots, and UI templates) in a user-specified directory, and updates them
+  incrementally via its API.
+
+
+  Example usage:
+
+  ```python
+  import model_card_toolkit
+
+  # Initialize the Model Card Toolkit with a path to store generate assets
+  model_card_output_path = ...
+  mct = model_card_toolkit.ModelCardToolkit(model_card_output_path)
+
+  # Initialize the ModelCard, which can be freely populated
+  model_card = mct.scaffold_assets()
+  model_card.model_details.name = 'My Model'
+
+  # Write the model card data to a JSON file
+  mct.update_model_card_json(model_card)
+
+  # Return the model card document as an HTML page
+  html = mct.export_format()
+  ```
   """
 
   def __init__(self,
                output_dir: Optional[Text] = None,
-               mlmd_store: Optional[metadata_store.MetadataStore] = None,
+               mlmd_store: Optional[mlmd.MetadataStore] = None,
                model_uri: Optional[Text] = None):
     """Initializes the ModelCardToolkit.
 
@@ -108,7 +133,7 @@ class ModelCardToolkit():
     with open(path, 'r') as f:
       return f.read()
 
-  def scaffold_assets(self) -> model_card_module.ModelCard:
+  def scaffold_assets(self) -> ModelCard:
     """Generates the model cards tookit assets.
 
     Model cards assets include the model card json file and customizable model
@@ -122,8 +147,11 @@ class ModelCardToolkit():
 
     Returns:
       A ModelCard representing the given model.
+
+    Raises:
+      FileNotFoundError: if it failed to copy the UI template files.
     """
-    model_card = model_card_module.ModelCard()
+    model_card = ModelCard()
     if self._store:
       model_card = tfx_util.generate_model_card_for_model(
           self._store, self._artifact_with_model_uri.id)
@@ -145,12 +173,19 @@ class ModelCardToolkit():
 
     # Write JSON file.
     self._write_file(self._mcta_json_file, model_card.to_json())
+
     # Write UI template files.
-    shutil.copytree(_UI_TEMPLATE_DIR, self._mcta_template_dir)
+    for template_path in _UI_TEMPLATES:
+      template_content = pkgutil.get_data('model_card_toolkit', template_path)
+      if template_content is None:
+        raise FileNotFoundError(f"Cannot find file: '{template_path}'")
+      template_content = template_content.decode('utf8')
+      self._write_file(
+          os.path.join(self.output_dir, template_path), template_content)
+
     return model_card
 
-  def update_model_card_json(self,
-                             model_card: model_card_module.ModelCard) -> None:
+  def update_model_card_json(self, model_card: ModelCard) -> None:
     """Validates the model card and updates the JSON file in MCT assets.
 
     If model_card.schema_version is not provided, it will assign the latest
@@ -163,14 +198,9 @@ class ModelCardToolkit():
        Error: when the given model_card is invalid w.r.t. the schema.
     """
     if not model_card.schema_version:
-      sub_directories = [f for f in os.scandir(_SCHEMA_DIR) if f.is_dir()]
-      latest_schema_version = max(
-          sub_directories, key=lambda f: semantic_version.Version(f.name[1:]))
-      model_card.schema_version = latest_schema_version.name[1:]
-    # Validate the updated model_card first.
-    schema = self._find_model_card_schema(model_card.schema_version)
-    jsonschema.validate(model_card.to_dict(), schema)
-    # Write the updated JSON to the file.
+      model_card.schema_version = validation.get_latest_schema_version()
+    validation.validate_json_schema(model_card.to_dict(),
+                                    model_card.schema_version)
     self._write_file(self._mcta_json_file, model_card.to_json())
 
   def export_format(self,
@@ -208,9 +238,9 @@ class ModelCardToolkit():
     # TODO(b/154990170) Think about how to adjust the img inside template.
     model_card_file_content = template.render(
         model_details=model_card['model_details'],
-        model_parameters=model_card['model_parameters'],
-        quantitative_analysis=model_card['quantitative_analysis'],
-        considerations=model_card['considerations'])
+        model_parameters=model_card.get('model_parameters', {}),
+        quantitative_analysis=model_card.get('quantitative_analysis', {}),
+        considerations=model_card.get('considerations', {}))
 
     # Write the model card file.
     mode_card_file_path = os.path.join(self._model_cards_dir, output_file)
@@ -221,32 +251,3 @@ class ModelCardToolkit():
   def save_mlmd(self) -> None:
     """Saves the model card of the model artifact with `model_uri` to MLMD."""
     pass
-
-  def _find_model_card_schema(self, version: Text) -> Dict[Text, Any]:
-    """Finds the model card JSON schema of a particular version.
-
-    A model card is created w.r.t. to ModelCard json schema. The MCT contains
-    a list of known Model Card JSON schemas. The util looks for the json schema
-    file at a particular version and returns for validation.
-
-    Args:
-      version: The version of the schema.
-
-    Returns:
-      Json schema.
-
-    Raises:
-      ValueError if cannot find the expect schema given the version.
-    """
-    sub_directories = [f for f in os.scandir(_SCHEMA_DIR) if f.is_dir()]
-    # Remove the first charactor 'v' from path when comparing.
-    matching_dir = [f for f in sub_directories if str(f.name[1:]) == version]
-    if not matching_dir:
-      raise ValueError(
-          'Cannot find schema version that matches the version of the given '
-          'model card. Found Versions: {}. Given Version: {}'.format(
-              str([str(f.name[1:]) for f in sub_directories]), version))
-    schema_file = os.path.join(str(matching_dir[0].path), _SCHEMA_FILE_NAME)
-    with open(schema_file) as json_file:
-      schema = json.loads(json_file.read())
-    return schema
